.. Copyright 2013, 2014, 2016 Reahl Software Services (Pty) Ltd. All rights reserved.

Modules reahl.domainui.workflow and reahl.domainui.bootstrap.workflow
---------------------------------------------------------------------

.. note::

   These modules have identical APIs.

The old version (reahl.domainui.workflow)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: reahl.domainui.workflow


InboxUI
"""""""

.. autoclass:: InboxUI
   :members:

TaskWidget
""""""""""

.. autoclass:: TaskWidget
   :members:


The Bootstrap-styled version (reahl.domainui.bootstrap.workflow)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: reahl.domainui.bootstrap.workflow


InboxUI
"""""""

.. autoclass:: InboxUI
   :members:

TaskWidget
""""""""""

.. autoclass:: TaskWidget
   :members:
